@@ -2,15 +2,14 @@ package core_test
 
 import (
 	"context"
-	"fmt"
+	"errors"
 	"reflect"
 	"testing"
 	"time"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/args"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 	"github.com/stretchr/testify/assert"
-
-	"github.com/scaleway/scaleway-cli/v2/internal/args"
 )
 
 type testType struct {
@@ -116,7 +115,7 @@ func Test_handleUnmarshalErrors(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckExitCode(1),
 			core.TestCheckError(&core.CliError{
-				Err:  fmt.Errorf("invalid argument 'name_id': arg name must only contain lowercase letters, numbers or dashes"),
+				Err:  errors.New("invalid argument 'name_id': arg name must only contain lowercase letters, numbers or dashes"),
 				Hint: "Valid arguments are: name-id",
 			}),
 		),
@@ -128,7 +127,7 @@ func Test_handleUnmarshalErrors(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckExitCode(1),
 			core.TestCheckError(&core.CliError{
-				Err:  fmt.Errorf("invalid argument 'ubuntu_focal': arg name must only contain lowercase letters, numbers or dashes"),
+				Err:  errors.New("invalid argument 'ubuntu_focal': arg name must only contain lowercase letters, numbers or dashes"),
 				Hint: "Valid arguments are: name-id",
 			}),
 		),
@@ -144,7 +143,7 @@ func Test_handleUnmarshalErrors(t *testing.T) {
 				Details: `Absolute time error: parsing time "+3R" as "2006-01-02T15:04:05Z07:00": cannot parse "+3R" as "2006"
 Relative time error: unknown unit in duration: "R"
 `,
-				Err:  fmt.Errorf("date parsing error: +3R"),
+				Err:  errors.New("date parsing error: +3R"),
 				Hint: "Run `scw help date` to learn more about date parsing",
 			}),
 		),
@@ -178,7 +177,7 @@ func Test_PositionalArg(t *testing.T) {
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(1),
 				core.TestCheckError(&core.CliError{
-					Err:  fmt.Errorf("a positional argument is required for this command"),
+					Err:  errors.New("a positional argument is required for this command"),
 					Hint: "Try running: scw test positional <name-id>",
 				}),
 			),
@@ -190,7 +189,7 @@ func Test_PositionalArg(t *testing.T) {
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(1),
 				core.TestCheckError(&core.CliError{
-					Err:  fmt.Errorf("a positional argument is required for this command"),
+					Err:  errors.New("a positional argument is required for this command"),
 					Hint: "Try running: scw test positional <name-id> tag=world",
 				}),
 			),
@@ -202,7 +201,7 @@ func Test_PositionalArg(t *testing.T) {
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(1),
 				core.TestCheckError(&core.CliError{
-					Err:  fmt.Errorf("a positional argument is required for this command"),
+					Err:  errors.New("a positional argument is required for this command"),
 					Hint: "Try running: scw test positional plop tag=world",
 				}),
 			),
@@ -214,7 +213,7 @@ func Test_PositionalArg(t *testing.T) {
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(1),
 				core.TestCheckError(&core.CliError{
-					Err:  fmt.Errorf("a positional argument is required for this command"),
+					Err:  errors.New("a positional argument is required for this command"),
 					Hint: "Try running: scw test positional plop tag=world",
 				}),
 			),
@@ -226,7 +225,7 @@ func Test_PositionalArg(t *testing.T) {
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(1),
 				core.TestCheckError(&core.CliError{
-					Err:  fmt.Errorf("a positional argument is required for this command"),
+					Err:  errors.New("a positional argument is required for this command"),
 					Hint: "Try running: scw test positional plop",
 				}),
 			),
@@ -281,8 +280,9 @@ func Test_MultiPositionalArg(t *testing.T) {
 			core.TestCheckExitCode(0),
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				res := ctx.Result.(*testAcceptMultiPositionalArgsType)
-				assert.Equal(t, 1, len(res.NameIDs))
+				assert.Len(t, res.NameIDs, 1)
 				assert.Equal(t, "pos1", res.NameIDs[0])
 				assert.Equal(t, "tag1", res.Tag)
 			},
@@ -296,8 +296,9 @@ func Test_MultiPositionalArg(t *testing.T) {
 			core.TestCheckExitCode(0),
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				res := ctx.Result.(*testAcceptMultiPositionalArgsType)
-				assert.Equal(t, 3, len(res.NameIDs))
+				assert.Len(t, res.NameIDs, 3)
 				assert.Equal(t, "pos1", res.NameIDs[0])
 				assert.Equal(t, "pos2", res.NameIDs[1])
 				assert.Equal(t, "pos3", res.NameIDs[2])
@@ -312,7 +313,7 @@ func Test_MultiPositionalArg(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckExitCode(1),
 			core.TestCheckError(&core.CliError{
-				Err:  fmt.Errorf("a positional argument is required for this command"),
+				Err:  errors.New("a positional argument is required for this command"),
 				Hint: "Try running: scw test multi-positional <name-ids> tag=tag1",
 			}),
 		),
