@@ -1,4 +1,4 @@
-package e2e
+package e2e_test
 
 import (
 	"testing"
@@ -8,6 +8,8 @@ import (
 )
 
 func TestStandardErrors(t *testing.T) {
+	t.Skip("Test API not available")
+
 	t.Run("unknown-command", core.Test(&core.TestConfig{
 		Commands:        test.GetCommands(),
 		UseE2EClient:    true,
