@@ -5,9 +5,8 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/gofields"
-
 	"github.com/alecthomas/assert"
+	"github.com/scaleway/scaleway-cli/v2/internal/gofields"
 )
 
 type Friends struct {
@@ -46,6 +45,7 @@ func TestGetValue(t *testing.T) {
 
 	run := func(tc *TestCase) func(*testing.T) {
 		return func(t *testing.T) {
+			t.Helper()
 			actual, err := gofields.GetValue(tc.Data, tc.Path)
 			if err != nil {
 				assert.Equal(t, tc.Expected, err.Error())
@@ -67,7 +67,7 @@ func TestGetValue(t *testing.T) {
 			},
 		},
 		Pets: map[string]*Pet{
-			"rex": &Pet{
+			"rex": {
 				Animal: Animal{
 					Species: "dog",
 				},
@@ -155,6 +155,7 @@ func TestGetType(t *testing.T) {
 
 	run := func(tc *TestCase) func(*testing.T) {
 		return func(t *testing.T) {
+			t.Helper()
 			actual, err := gofields.GetType(tc.Data, tc.Path)
 			if err != nil {
 				assert.Equal(t, tc.Expected, err.Error())
@@ -230,6 +231,7 @@ func TestListFields(t *testing.T) {
 
 	run := func(tc *TestCase) func(*testing.T) {
 		return func(t *testing.T) {
+			t.Helper()
 			actual := gofields.ListFields(tc.Data)
 			assert.Equal(t, tc.Expected, actual)
 		}
@@ -250,6 +252,7 @@ func TestListFieldsWithFilter(t *testing.T) {
 
 	run := func(tc *TestCase) func(*testing.T) {
 		return func(t *testing.T) {
+			t.Helper()
 			actual := gofields.ListFieldsWithFilter(tc.Data, tc.Filter)
 			assert.Equal(t, tc.Expected, actual)
 		}
