@@ -8,9 +8,10 @@ import (
 
 // MarshalOpt is hydrated by core.View
 type MarshalOpt struct {
-	Title    string
-	Fields   []*MarshalFieldOpt
-	Sections []*MarshalSection
+	Title      string
+	Fields     []*MarshalFieldOpt
+	Sections   []*MarshalSection
+	SubOptions map[string]*MarshalOpt
 
 	// Is set to true if we are marshaling a table cell
 	TableCell bool
@@ -19,6 +20,15 @@ type MarshalOpt struct {
 	DisableShrinking bool
 }
 
+func (m *MarshalOpt) subOption(section string) *MarshalOpt {
+	subOpt, exists := m.SubOptions[section]
+	if exists {
+		return subOpt
+	}
+
+	return &MarshalOpt{}
+}
+
 type MarshalFieldOpt struct {
 	FieldName string
 	Label     string
