@@ -6,9 +6,8 @@ import (
 	"fmt"
 	"net/http"
 	"reflect"
-	"time"
-
 	"strings"
+	"time"
 
 	"github.com/fatih/color"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
@@ -27,15 +26,13 @@ const (
 	serverActionReboot
 )
 
-var (
-	serverStatusMarshalSpecs = human.EnumMarshalSpecs{
-		applesilicon.ServerStatusError:     &human.EnumMarshalSpec{Attribute: color.FgRed, Value: "error"},
-		applesilicon.ServerStatusReady:     &human.EnumMarshalSpec{Attribute: color.FgGreen, Value: "ready"},
-		applesilicon.ServerStatusRebooting: &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "rebooting"},
-		applesilicon.ServerStatusStarting:  &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "starting"},
-		applesilicon.ServerStatusUpdating:  &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "updating"},
-	}
-)
+var serverStatusMarshalSpecs = human.EnumMarshalSpecs{
+	applesilicon.ServerStatusError:     &human.EnumMarshalSpec{Attribute: color.FgRed, Value: "error"},
+	applesilicon.ServerStatusReady:     &human.EnumMarshalSpec{Attribute: color.FgGreen, Value: "ready"},
+	applesilicon.ServerStatusRebooting: &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "rebooting"},
+	applesilicon.ServerStatusStarting:  &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "starting"},
+	applesilicon.ServerStatusUpdating:  &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "updating"},
+}
 
 func serverCreateBuilder(c *core.Command) *core.Command {
 	c.ArgSpecs.GetByName("type").AutoCompleteFunc = autocompleteServerType
