@@ -1,7 +1,7 @@
 package iam_test
 
 import (
-	"fmt"
+	"errors"
 	"testing"
 
 	"github.com/alecthomas/assert"
@@ -23,6 +23,7 @@ func Test_createRule(t *testing.T) {
 		Cmd: `scw iam rule create {{ .Policy.ID }} permission-set-names.0=VPCReadOnly project-ids.0={{ .Project.ID }}`,
 		Check: core.TestCheckCombine(
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				assert.Contains(t, string(ctx.Stdout), "IPAMReadOnly")
 				assert.Contains(t, string(ctx.Stdout), "VPCReadOnly")
 			},
@@ -50,7 +51,7 @@ func Test_deleteRule(t *testing.T) {
 				// Get first Rule ID
 				policy := ctx.Meta["Policy"].(*iam.PolicyGetInterceptorResponse)
 				if len(policy.Rules) != 2 {
-					return fmt.Errorf("expected two rules in policy")
+					return errors.New("expected two rules in policy")
 				}
 				ctx.Meta["Rule"] = policy.Rules[0]
 
@@ -60,6 +61,7 @@ func Test_deleteRule(t *testing.T) {
 		Cmd: `scw iam rule delete {{ .Policy.ID }} rule-id={{ .Rule.ID }}`,
 		Check: core.TestCheckCombine(
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				assert.NotContains(t, string(ctx.Stdout), "IPAMReadOnly")
 				assert.Contains(t, string(ctx.Stdout), "VPCReadOnly")
 			},
