@@ -2,6 +2,7 @@ package init
 
 import (
 	"context"
+	"errors"
 	"fmt"
 
 	"github.com/fatih/color"
@@ -21,7 +22,7 @@ func promptOrganizationID(ctx context.Context) (string, error) {
 		Prompt: "Choose your default organization ID",
 		ValidateFunc: func(s string) error {
 			if !validation.IsUUID(s) {
-				return fmt.Errorf("organization id is not a valid uuid")
+				return errors.New("organization id is not a valid uuid")
 			}
 			return nil
 		},
@@ -37,7 +38,7 @@ func promptManualProjectID(ctx context.Context, defaultProjectID string) (string
 		DefaultValueDoc: defaultProjectID,
 		ValidateFunc: func(s string) error {
 			if !validation.IsProjectID(s) {
-				return fmt.Errorf("organization id is not a valid uuid")
+				return errors.New("organization id is not a valid uuid")
 			}
 			return nil
 		},
@@ -135,8 +136,7 @@ func promptSecretKey(ctx context.Context) (string, error) {
 		Ctx: ctx,
 		PromptFunc: func(value string) string {
 			secretKey := "secret-key"
-			switch {
-			case validation.IsUUID(value):
+			if validation.IsUUID(value) {
 				secretKey = terminal.Style(secretKey, color.FgBlue)
 			}
 			return terminal.Style(fmt.Sprintf("Enter a valid %s: ", secretKey), color.Bold)
@@ -146,7 +146,7 @@ func promptSecretKey(ctx context.Context) (string, error) {
 			if validation.IsSecretKey(s) {
 				return nil
 			}
-			return fmt.Errorf("invalid secret-key")
+			return errors.New("invalid secret-key")
 		},
 	})
 	if err != nil {
@@ -168,15 +168,14 @@ func promptAccessKey(ctx context.Context) (string, error) {
 		Ctx: ctx,
 		PromptFunc: func(value string) string {
 			accessKey := "access-key"
-			switch {
-			case validation.IsAccessKey(value):
+			if validation.IsAccessKey(value) {
 				accessKey = terminal.Style(accessKey, color.FgBlue)
 			}
 			return terminal.Style(fmt.Sprintf("Enter a valid %s: ", accessKey), color.Bold)
 		},
 		ValidateFunc: func(s string) error {
 			if !validation.IsAccessKey(s) {
-				return fmt.Errorf("invalid access-key")
+				return errors.New("invalid access-key")
 			}
 
 			return nil
@@ -205,7 +204,7 @@ func promptDefaultZone(ctx context.Context) (scw.Zone, error) {
 		ValidateFunc: func(s string) error {
 			logger.Debugf("s: %v", s)
 			if !validation.IsZone(s) {
-				return fmt.Errorf("invalid zone")
+				return errors.New("invalid zone")
 			}
 			return nil
 		},
@@ -242,7 +241,7 @@ func promptProfileOverride(ctx context.Context, config *scw.Config, configPath s
 			return err
 		}
 		if !overrideConfig {
-			return fmt.Errorf("initialization canceled")
+			return errors.New("initialization canceled")
 		}
 	}
 
