@@ -10,13 +10,11 @@ import (
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 )
 
-var (
-	privateNICStateMarshalSpecs = human.EnumMarshalSpecs{
-		instance.PrivateNICStateAvailable:    &human.EnumMarshalSpec{Attribute: color.FgGreen},
-		instance.PrivateNICStateSyncing:      &human.EnumMarshalSpec{Attribute: color.FgBlue},
-		instance.PrivateNICStateSyncingError: &human.EnumMarshalSpec{Attribute: color.FgRed},
-	}
-)
+var privateNICStateMarshalSpecs = human.EnumMarshalSpecs{
+	instance.PrivateNICStateAvailable:    &human.EnumMarshalSpec{Attribute: color.FgGreen},
+	instance.PrivateNICStateSyncing:      &human.EnumMarshalSpec{Attribute: color.FgBlue},
+	instance.PrivateNICStateSyncingError: &human.EnumMarshalSpec{Attribute: color.FgRed},
+}
 
 func privateNicGetBuilder(c *core.Command) *core.Command {
 	c.ArgSpecs.GetByName("private-nic-id").Short = "The private NIC unique ID or MAC address"
