@@ -397,10 +397,12 @@ func serverGetBuilder(c *core.Command) *core.Command {
 			{
 				FieldName: "Image",
 				Title:     "Server Image",
-			}, {
+			},
+			{
 				FieldName: "AllowedActions",
 				Title:     "Allowed Actions",
-			}, {
+			},
+			{
 				FieldName: "Volumes",
 				Title:     "Volumes",
 			},
@@ -619,9 +621,9 @@ func serverDetachIPCommand() *core.Command {
 					}
 					return api.GetServer(&instance.GetServerRequest{ServerID: args.ServerID})
 				}
-				return nil, fmt.Errorf("no public ip found")
+				return nil, errors.New("no public ip found")
 			}
-			return nil, fmt.Errorf("no server found")
+			return nil, errors.New("no server found")
 		},
 		Examples: []*core.Example{
 			{
