@@ -3,11 +3,10 @@ package instance_test
 import (
 	"testing"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
-
 	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/interactive"
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
 	instanceSDK "github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
 	"github.com/stretchr/testify/require"
@@ -26,6 +25,7 @@ func Test_ServerTerminate(t *testing.T) {
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				api := instanceSDK.NewAPI(ctx.Client)
 				server := ctx.Meta["Server"].(*instanceSDK.Server)
 				_, err := api.GetIP(&instanceSDK.GetIPRequest{
@@ -46,6 +46,7 @@ func Test_ServerTerminate(t *testing.T) {
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				api := instanceSDK.NewAPI(ctx.Client)
 				server := ctx.Meta["Server"].(*instanceSDK.Server)
 				_, err := api.GetIP(&instanceSDK.GetIPRequest{
@@ -81,6 +82,7 @@ func Test_ServerTerminate(t *testing.T) {
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				api := instanceSDK.NewAPI(ctx.Client)
 				server := ctx.Meta["Server"].(*instanceSDK.Server)
 				_, err := api.GetVolume(&instanceSDK.GetVolumeRequest{
@@ -122,6 +124,7 @@ func Test_ServerAction(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				storedServer := ctx.Meta["Server"].(*instanceSDK.Server)
 				api := instanceSDK.NewAPI(ctx.Client)
 				resp, err := api.GetServer(&instanceSDK.GetServerRequest{
@@ -142,10 +145,11 @@ func Test_ServerAction(t *testing.T) {
 func Test_ServerEnableRoutedIP(t *testing.T) {
 	t.Run("simple", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create zone=fr-par-3 type=PRO2-XXS image=ubuntu_jammy ip=new --wait"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create zone=fr-par-3 type=PRO2-XXS image=ubuntu_jammy routed-ip-enabled=false ip=new --wait"),
 		Cmd:        `scw instance server enable-routed-ip zone=fr-par-3 {{ .Server.ID }} --wait`,
 		Check: core.TestCheckCombine(
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				storedServer := ctx.Meta["Server"].(*instanceSDK.Server)
 				api := instanceSDK.NewAPI(ctx.Client)
 				server, err := api.GetServer(&instanceSDK.GetServerRequest{
