@@ -3,14 +3,15 @@ package instance
 import (
 	"bytes"
 	"context"
+	"errors"
 	"fmt"
-	"net"
 	"reflect"
 	"strconv"
 	"strings"
 
 	"github.com/dustin/go-humanize"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	block "github.com/scaleway/scaleway-sdk-go/api/block/v1alpha1"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/marketplace/v2"
 	"github.com/scaleway/scaleway-sdk-go/logger"
@@ -44,7 +45,7 @@ type instanceCreateServerRequest struct {
 	CloudInit    string
 	BootType     string
 
-	// Deprecated, use project-id instead
+	// Deprecated: use project-id instead
 	OrganizationID *string
 }
 
@@ -99,7 +100,7 @@ func serverCreateCommand() *core.Command {
 			},
 			{
 				Name:  "ipv6",
-				Short: "Enable IPv6",
+				Short: "Enable IPv6, to be used with routed-ip-enabled=false",
 			},
 			{
 				Name:  "stopped",
@@ -113,10 +114,6 @@ func serverCreateCommand() *core.Command {
 				Name:  "placement-group-id",
 				Short: "The placement group ID in which the server has to be created",
 			},
-			{
-				Name:  "bootscript-id",
-				Short: "The bootscript ID to use, if empty the local boot will be used",
-			},
 			{
 				Name:        "cloud-init",
 				Short:       "The cloud-init script to use",
@@ -168,6 +165,14 @@ func serverCreateCommand() *core.Command {
 				Short:    "Create an instance with volumes from snapshots",
 				ArgsJSON: `{"image":"ubuntu_focal","root_volume":"local:<snapshot_id>","additional_volumes":["block:<snapshot_id>"]}`,
 			},
+			{
+				Short:    "Create and start an instance from a snapshot",
+				ArgsJSON: `{"image":"none","root_volume":"local:<snapshot_id>"}`,
+			},
+			{
+				Short:    "Create and start an instance using existing volume",
+				ArgsJSON: `{"image":"ubuntu_focal","additional_volumes":["<volume_id>"]}`,
+			},
 			{
 				Short: "Use an existing IP",
 				Raw: `ip=$(scw instance ip create | grep id | awk '{ print $2 }')
@@ -189,233 +194,84 @@ func instanceWaitServerCreateRun() core.WaitFunc {
 }
 
 func instanceServerCreateRun(ctx context.Context, argsI interface{}) (i interface{}, e error) {
+	var err error
 	args := argsI.(*instanceCreateServerRequest)
 
 	//
-	// STEP 1: Argument validation and API requests creation.
+	// STEP 1: Argument handling and API requests creation.
 	//
 
-	needIPCreation := false
-
-	serverReq := &instance.CreateServerRequest{
-		Zone:                            args.Zone,
-		Organization:                    args.OrganizationID,
-		Project:                         args.ProjectID,
-		Name:                            args.Name,
-		CommercialType:                  args.Type,
-		EnableIPv6:                      scw.BoolPtr(args.IPv6),
-		Tags:                            args.Tags,
-		RoutedIPEnabled:                 args.RoutedIPEnabled,
-		AdminPasswordEncryptionSSHKeyID: args.AdminPasswordEncryptionSSHKeyID,
-	}
-
 	client := core.ExtractClient(ctx)
-	apiMarketplace := marketplace.NewAPI(client)
+
+	serverBuilder := NewServerBuilder(client, args.Name, args.Zone, args.Type).
+		AddOrganizationID(args.OrganizationID).
+		AddProjectID(args.ProjectID).
+		AddEnableIPv6(scw.BoolPtr(args.IPv6)).
+		AddTags(args.Tags).
+		AddRoutedIPEnabled(args.RoutedIPEnabled).
+		AddAdminPasswordEncryptionSSHKeyID(args.AdminPasswordEncryptionSSHKeyID).
+		AddBootType(args.BootType).
+		AddSecurityGroup(args.SecurityGroupID).
+		AddPlacementGroup(args.PlacementGroupID)
+
+	serverBuilder, err = serverBuilder.AddVolumes(args.RootVolume, args.AdditionalVolumes)
+	if err != nil {
+		return nil, err
+	}
+
+	serverBuilder, err = serverBuilder.AddImage(args.Image)
+	if err != nil {
+		return nil, err
+	}
+
+	serverBuilder, err = serverBuilder.AddIP(args.IP)
+	if err != nil {
+		return nil, err
+	}
+
+	//
+	// STEP 2: Validation and requests
+	//
+
+	err = serverBuilder.Validate()
+	if err != nil {
+		return nil, err
+	}
+
+	createReq, createIPReq := serverBuilder.Build()
+	needIPCreation := createIPReq != nil
+
+	//
+	// IP creation
+	//
 	apiInstance := instance.NewAPI(client)
 
-	if commercialTypeIsWindowsServer(serverReq.CommercialType) && serverReq.AdminPasswordEncryptionSSHKeyID == nil {
-		return nil, &core.CliError{
-			Err:     core.MissingRequiredArgumentError("admin-password-encryption-ssh-key-id").Err,
-			Details: "Expected a SSH Key ID to encrypt Admin RDP password. If not provided, no password will be generated. Key must be RSA Public Key.",
-			Hint:    "Use completion or get your ssh key id using 'scw iam ssh-key list',",
-			Code:    1,
-			Empty:   false,
-		}
-	}
-
-	//
-	// Image.
-	//
-	// Could be:
-	// - A local image UUID
-	// - An image label
-	//
-	switch {
-	case !validation.IsUUID(args.Image):
-		// For retro-compatibility, we replace dashes with underscores
-		imageLabel := strings.Replace(args.Image, "-", "_", -1)
-
-		// Find the corresponding local image UUID.
-		localImage, err := apiMarketplace.GetLocalImageByLabel(&marketplace.GetLocalImageByLabelRequest{
-			ImageLabel:     imageLabel,
-			Zone:           args.Zone,
-			CommercialType: serverReq.CommercialType,
-			Type:           marketplace.LocalImageTypeInstanceLocal,
-		})
-		if err != nil {
-			return nil, err
-		}
-		serverReq.Image = localImage.ID
-	default:
-		serverReq.Image = args.Image
-	}
-
-	getImageResponse, err := apiInstance.GetImage(&instance.GetImageRequest{
-		Zone:    args.Zone,
-		ImageID: serverReq.Image,
-	})
-	if err != nil {
-		logger.Warningf("cannot get image %s: %s", serverReq.Image, err)
-	}
-
-	serverType := getServerType(apiInstance, serverReq.Zone, serverReq.CommercialType)
-
-	if serverType != nil && getImageResponse != nil {
-		if err := validateImageServerTypeCompatibility(getImageResponse.Image, serverType, serverReq.CommercialType); err != nil {
-			return nil, err
-		}
-	} else {
-		logger.Warningf("skipping image server-type compatibility validation")
-	}
-
-	//
-	// IP.
-	//
-	// Could be:
-	// - "new"
-	// - A flexible IP UUID
-	// - A flexible IP address
-	// - "dynamic"
-	// - "none"
-	//
-	switch {
-	case args.IP == "", args.IP == "new":
-		needIPCreation = true
-	case validation.IsUUID(args.IP):
-		serverReq.PublicIP = scw.StringPtr(args.IP)
-	case net.ParseIP(args.IP) != nil:
-		// Find the corresponding flexible IP UUID.
-		logger.Debugf("finding public IP UUID from address: %s", args.IP)
-		res, err := apiInstance.GetIP(&instance.GetIPRequest{
-			Zone: args.Zone,
-			IP:   args.IP,
-		})
-		if err != nil { // FIXME: isNotFoundError
-			return nil, fmt.Errorf("%s does not belong to you", args.IP)
-		}
-		serverReq.PublicIP = scw.StringPtr(res.IP.ID)
-	case args.IP == "dynamic":
-		serverReq.DynamicIPRequired = scw.BoolPtr(true)
-	case args.IP == "none":
-		serverReq.DynamicIPRequired = scw.BoolPtr(false)
-	default:
-		return nil, fmt.Errorf(`invalid IP "%s", should be either 'new', 'dynamic', 'none', an IP address ID or a reserved flexible IP address`, args.IP)
-	}
-
-	//
-	// Volumes.
-	//
-	// More format details in buildVolumeTemplate function.
-	//
-	if len(args.AdditionalVolumes) > 0 || args.RootVolume != "" {
-		// Create initial volume template map.
-		volumes, err := buildVolumes(apiInstance, args.Zone, serverReq.Name, args.RootVolume, args.AdditionalVolumes)
-		if err != nil {
-			return nil, err
-		}
-
-		// Validate root volume type and size.
-		if getImageResponse != nil {
-			if err := validateRootVolume(getImageResponse.Image.RootVolume.Size, volumes["0"]); err != nil {
-				return nil, err
-			}
-		} else {
-			logger.Warningf("skipping root volume validation")
-		}
-
-		// Validate total local volume sizes.
-		if serverType != nil && getImageResponse != nil {
-			if err := validateLocalVolumeSizes(volumes, serverType, serverReq.CommercialType, getImageResponse.Image.RootVolume.Size); err != nil {
-				return nil, err
-			}
-		} else {
-			logger.Warningf("skip local volume size validation")
-		}
-
-		// Sanitize the volume map to respect API schemas
-		serverReq.Volumes = sanitizeVolumeMap(serverReq.Name, volumes)
-	}
-
-	// Add default volumes to server, ex: scratch storage for GPU servers
-	if serverType != nil {
-		serverReq.Volumes = addDefaultVolumes(serverType, serverReq.Volumes)
-	}
-
-	//
-	// BootType.
-	//
-	bootType := instance.BootType(args.BootType)
-	serverReq.BootType = &bootType
-
-	//
-	// Bootscript.
-	//
-	if args.BootscriptID != "" {
-		if !validation.IsUUID(args.BootscriptID) {
-			return nil, fmt.Errorf("bootscript ID %s is not a valid UUID", args.BootscriptID)
-		}
-		//nolint: staticcheck // Bootscript is deprecated
-		_, err := apiInstance.GetBootscript(&instance.GetBootscriptRequest{
-			Zone:         args.Zone,
-			BootscriptID: args.BootscriptID,
-		})
-		if err != nil { // FIXME: isNotFoundError
-			return nil, fmt.Errorf("bootscript ID %s does not exist", args.BootscriptID)
-		}
-
-		//nolint: staticcheck // Bootscript is deprecated
-		serverReq.Bootscript = scw.StringPtr(args.BootscriptID)
-		bootType := instance.BootTypeBootscript
-		serverReq.BootType = &bootType
-	}
-
-	//
-	// Security Group.
-	//
-	if args.SecurityGroupID != "" {
-		serverReq.SecurityGroup = scw.StringPtr(args.SecurityGroupID)
-	}
-
-	//
-	// Placement Group.
-	//
-	if args.PlacementGroupID != "" {
-		serverReq.PlacementGroup = scw.StringPtr(args.PlacementGroupID)
-	}
-
-	//
-	// STEP 2: Resource creations and modifications.
-	//
-
-	//
-	// IP
-	//
 	if needIPCreation {
 		logger.Debugf("creating IP")
 
-		ip, err := instanceServerCreateIPCreate(args, apiInstance)
+		ipRes, err := apiInstance.CreateIP(createIPReq)
 		if err != nil {
 			return nil, fmt.Errorf("error while creating your public IP: %s", err)
 		}
-		serverReq.PublicIP = scw.StringPtr(ip.ID)
-		logger.Debugf("IP created: %s", serverReq.PublicIP)
+		createReq.PublicIP = scw.StringPtr(ipRes.IP.ID)
+		logger.Debugf("IP created: %s", createReq.PublicIP)
 	}
 
 	//
 	// Server Creation
 	//
 	logger.Debugf("creating server")
-	serverRes, err := apiInstance.CreateServer(serverReq)
+	serverRes, err := apiInstance.CreateServer(createReq)
 	if err != nil {
-		if needIPCreation && serverReq.PublicIP != nil {
+		if needIPCreation && createReq.PublicIP != nil {
 			// Delete the created IP
-			logger.Debugf("deleting created IP: %s", serverReq.PublicIP)
+			logger.Debugf("deleting created IP: %s", createReq.PublicIP)
 			err := apiInstance.DeleteIP(&instance.DeleteIPRequest{
 				Zone: args.Zone,
-				IP:   *serverReq.PublicIP,
+				IP:   *createReq.PublicIP,
 			})
 			if err != nil {
-				logger.Warningf("cannot delete the create IP %s: %s.", serverReq.PublicIP, err)
+				logger.Warningf("cannot delete the create IP %s: %s.", createReq.PublicIP, err)
 			}
 		}
 
@@ -503,10 +359,10 @@ func addDefaultVolumes(serverType *instance.ServerType, volumes map[string]*inst
 
 // buildVolumes creates the initial volume map.
 // It is not the definitive one, it will be mutated all along the process.
-func buildVolumes(api *instance.API, zone scw.Zone, serverName, rootVolume string, additionalVolumes []string) (map[string]*instance.VolumeServerTemplate, error) {
+func buildVolumes(api *instance.API, blockAPI *block.API, zone scw.Zone, serverName, rootVolume string, additionalVolumes []string) (map[string]*instance.VolumeServerTemplate, error) {
 	volumes := make(map[string]*instance.VolumeServerTemplate)
 	if rootVolume != "" {
-		rootVolumeTemplate, err := buildVolumeTemplate(api, zone, rootVolume)
+		rootVolumeTemplate, err := buildVolumeTemplate(api, blockAPI, zone, rootVolume)
 		if err != nil {
 			return nil, err
 		}
@@ -515,21 +371,13 @@ func buildVolumes(api *instance.API, zone scw.Zone, serverName, rootVolume strin
 	}
 
 	for i, v := range additionalVolumes {
-		volumeTemplate, err := buildVolumeTemplate(api, zone, v)
+		volumeTemplate, err := buildVolumeTemplate(api, blockAPI, zone, v)
 		if err != nil {
 			return nil, err
 		}
 		index := strconv.Itoa(i + 1)
 		volumeTemplate.Name = scw.StringPtr(serverName + "-" + index)
 
-		// Remove extra data for API validation.
-		if volumeTemplate.ID != nil {
-			volumeTemplate = &instance.VolumeServerTemplate{
-				ID:   volumeTemplate.ID,
-				Name: volumeTemplate.Name,
-			}
-		}
-
 		volumes[index] = volumeTemplate
 	}
 
@@ -544,7 +392,7 @@ func buildVolumes(api *instance.API, zone scw.Zone, serverName, rootVolume strin
 // - a "creation" format: ^((local|l|block|b|scratch|s):)?\d+GB?$ (size is handled by go-humanize, so other sizes are supported)
 // - a "creation" format with a snapshot id: l:<uuid> b:<uuid>
 // - a UUID format
-func buildVolumeTemplate(api *instance.API, zone scw.Zone, flagV string) (*instance.VolumeServerTemplate, error) {
+func buildVolumeTemplate(api *instance.API, blockAPI *block.API, zone scw.Zone, flagV string) (*instance.VolumeServerTemplate, error) {
 	parts := strings.Split(strings.TrimSpace(flagV), ":")
 
 	// Create volume.
@@ -558,6 +406,8 @@ func buildVolumeTemplate(api *instance.API, zone scw.Zone, flagV string) (*insta
 			vt.VolumeType = instance.VolumeVolumeTypeBSSD
 		case "s", "scratch":
 			vt.VolumeType = instance.VolumeVolumeTypeScratch
+		case "sbs":
+			vt.VolumeType = instance.VolumeVolumeTypeSbsVolume
 		default:
 			return nil, fmt.Errorf("invalid volume type %s in %s volume", parts[0], flagV)
 		}
@@ -577,7 +427,7 @@ func buildVolumeTemplate(api *instance.API, zone scw.Zone, flagV string) (*insta
 
 	// UUID format.
 	if len(parts) == 1 && validation.IsUUID(parts[0]) {
-		return buildVolumeTemplateFromUUID(api, zone, parts[0])
+		return buildVolumeTemplateFromUUID(api, blockAPI, zone, parts[0])
 	}
 
 	return nil, &core.CliError{
@@ -591,11 +441,32 @@ func buildVolumeTemplate(api *instance.API, zone scw.Zone, flagV string) (*insta
 // Add volume types and sizes allow US to treat UUID volumes like the others and simplify the implementation.
 // The instance API refuse the type and the size for UUID volumes, therefore,
 // sanitizeVolumeMap function will remove them.
-func buildVolumeTemplateFromUUID(api *instance.API, zone scw.Zone, volumeUUID string) (*instance.VolumeServerTemplate, error) {
+func buildVolumeTemplateFromUUID(api *instance.API, blockAPI *block.API, zone scw.Zone, volumeUUID string) (*instance.VolumeServerTemplate, error) {
 	res, err := api.GetVolume(&instance.GetVolumeRequest{
 		Zone:     zone,
 		VolumeID: volumeUUID,
 	})
+	if err != nil && !core.IsNotFoundError(err) {
+		return nil, err
+	}
+
+	if res != nil {
+		// Check that volume is not already attached to a server.
+		if res.Volume.Server != nil {
+			return nil, fmt.Errorf("volume %s is already attached to %s server", res.Volume.ID, res.Volume.Server.ID)
+		}
+
+		return &instance.VolumeServerTemplate{
+			ID:         &res.Volume.ID,
+			VolumeType: res.Volume.VolumeType,
+			Size:       &res.Volume.Size,
+		}, nil
+	}
+
+	blockRes, err := blockAPI.GetVolume(&block.GetVolumeRequest{
+		Zone:     zone,
+		VolumeID: volumeUUID,
+	})
 	if err != nil {
 		if core.IsNotFoundError(err) {
 			return nil, fmt.Errorf("volume %s does not exist", volumeUUID)
@@ -603,15 +474,13 @@ func buildVolumeTemplateFromUUID(api *instance.API, zone scw.Zone, volumeUUID st
 		return nil, err
 	}
 
-	// Check that volume is not already attached to a server.
-	if res.Volume.Server != nil {
-		return nil, fmt.Errorf("volume %s is already attached to %s server", res.Volume.ID, res.Volume.Server.ID)
+	if len(blockRes.References) > 0 {
+		return nil, fmt.Errorf("volume %s is already attached to %s %s", blockRes.ID, blockRes.References[0].ProductResourceID, blockRes.References[0].ProductResourceType)
 	}
 
 	return &instance.VolumeServerTemplate{
-		ID:         &res.Volume.ID,
-		VolumeType: res.Volume.VolumeType,
-		Size:       &res.Volume.Size,
+		ID:         &blockRes.ID,
+		VolumeType: instance.VolumeVolumeTypeSbsVolume, // TODO: support snapshot
 	}, nil
 }
 
@@ -644,7 +513,7 @@ func buildVolumeTemplateFromSnapshot(api *instance.API, zone scw.Zone, snapshotU
 	}, nil
 }
 
-func validateImageServerTypeCompatibility(image *instance.Image, serverType *instance.ServerType, CommercialType string) error {
+func validateImageServerTypeCompatibility(image *instance.Image, serverType *instance.ServerType, commercialType string) error {
 	// An instance might not have any constraints on the local volume size
 	if serverType.VolumesConstraint.MaxSize == 0 {
 		return nil
@@ -655,7 +524,7 @@ func validateImageServerTypeCompatibility(image *instance.Image, serverType *ins
 			humanize.Bytes(uint64(image.RootVolume.Size)),
 			humanize.Bytes(uint64(serverType.VolumesConstraint.MinSize)),
 			humanize.Bytes(uint64(serverType.VolumesConstraint.MaxSize)),
-			CommercialType,
+			commercialType,
 		)
 	}
 
@@ -675,18 +544,23 @@ func validateLocalVolumeSizes(volumes map[string]*instance.VolumeServerTemplate,
 	volumeConstraint := serverType.VolumesConstraint
 
 	// If no root volume provided, count the default root volume size added by the API.
-	if rootVolume := volumes["0"]; rootVolume == nil {
-		localVolumeTotalSize += defaultRootVolumeSize
+	// Only count if server allows LSSD.
+	if rootVolume := volumes["0"]; rootVolume == nil &&
+		serverType.PerVolumeConstraint != nil &&
+		serverType.PerVolumeConstraint.LSSD != nil &&
+		serverType.PerVolumeConstraint.LSSD.MaxSize > 0 {
+		localVolumeTotalSize += defaultRootVolumeSize // defaultRootVolumeSize may be used for a block volume
 	}
 
 	if localVolumeTotalSize < volumeConstraint.MinSize || localVolumeTotalSize > volumeConstraint.MaxSize {
-		min := humanize.Bytes(uint64(volumeConstraint.MinSize))
+		minSize := humanize.Bytes(uint64(volumeConstraint.MinSize))
+		computedLocal := humanize.Bytes(uint64(localVolumeTotalSize))
 		if volumeConstraint.MinSize == volumeConstraint.MaxSize {
-			return fmt.Errorf("%s total local volume size must be equal to %s", commercialType, min)
+			return fmt.Errorf("%s total local volume size must be equal to %s, got %s", commercialType, minSize, computedLocal)
 		}
 
-		max := humanize.Bytes(uint64(volumeConstraint.MaxSize))
-		return fmt.Errorf("%s total local volume size must be between %s and %s", commercialType, min, max)
+		maxSize := humanize.Bytes(uint64(volumeConstraint.MaxSize))
+		return fmt.Errorf("%s total local volume size must be between %s and %s, got %s", commercialType, minSize, maxSize, computedLocal)
 	}
 
 	return nil
@@ -699,7 +573,7 @@ func validateRootVolume(imageRequiredSize scw.Size, rootVolume *instance.VolumeS
 
 	if rootVolume.ID != nil {
 		return &core.CliError{
-			Err:     fmt.Errorf("you cannot use an existing volume as a root volume"),
+			Err:     errors.New("you cannot use an existing volume as a root volume"),
 			Details: "You must create an image of this volume and use its ID in the 'image' argument.",
 		}
 	}
@@ -721,9 +595,16 @@ func sanitizeVolumeMap(serverName string, volumes map[string]*instance.VolumeSer
 		// Remove extra data for API validation.
 		switch {
 		case v.ID != nil:
-			v = &instance.VolumeServerTemplate{
-				ID:   v.ID,
-				Name: v.Name,
+			if v.VolumeType == instance.VolumeVolumeTypeSbsVolume {
+				v = &instance.VolumeServerTemplate{
+					ID:         v.ID,
+					VolumeType: v.VolumeType,
+				}
+			} else {
+				v = &instance.VolumeServerTemplate{
+					ID:   v.ID,
+					Name: v.Name,
+				}
 			}
 		case v.BaseSnapshot != nil:
 			v = &instance.VolumeServerTemplate{
@@ -760,7 +641,7 @@ func instanceServerCreateImageAutoCompleteFunc(ctx context.Context, prefix strin
 		completeListImagesCache = res
 	}
 
-	prefix = strings.ToLower(strings.Replace(prefix, "-", "_", -1))
+	prefix = strings.ToLower(strings.ReplaceAll(prefix, "-", "_"))
 
 	for _, image := range completeListImagesCache.Images {
 		if strings.HasPrefix(image.Label, prefix) {
@@ -789,26 +670,3 @@ func getServerType(apiInstance *instance.API, zone scw.Zone, commercialType stri
 
 	return serverType
 }
-
-func instanceServerCreateIPCreate(args *instanceCreateServerRequest, api *instance.API) (*instance.IP, error) {
-	req := &instance.CreateIPRequest{
-		Zone:         args.Zone,
-		Project:      args.ProjectID,
-		Organization: args.OrganizationID,
-	}
-
-	if args.RoutedIPEnabled != nil {
-		if *args.RoutedIPEnabled {
-			req.Type = instance.IPTypeRoutedIPv4
-		} else {
-			req.Type = instance.IPTypeNat
-		}
-	}
-
-	res, err := api.CreateIP(req)
-	if err != nil {
-		return nil, err
-	}
-
-	return res.IP, nil
-}
