@@ -3,13 +3,13 @@ package instance
 import (
 	"context"
 	"encoding/base64"
+	"encoding/binary"
+	"errors"
 	"fmt"
 	"hash/crc32"
 	"reflect"
 	"strings"
 
-	"encoding/binary"
-
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
@@ -112,7 +112,8 @@ Lookup /root/.ssh/authorized_keys on your server for more information`,
 				}
 			}
 
-			tags := append(server.Server.Tags, formattedKey)
+			tags := server.Server.Tags
+			tags = append(tags, formattedKey)
 
 			_, err = api.UpdateServer(&instance.UpdateServerRequest{
 				Zone:     args.Zone,
@@ -245,7 +246,7 @@ Lookup /root/.ssh/authorized_keys on your server for more information`,
 			}
 
 			if len(removedKeys) == 0 {
-				return nil, fmt.Errorf("no key found with given filters")
+				return nil, errors.New("no key found with given filters")
 			}
 
 			_, err = api.UpdateServer(&instance.UpdateServerRequest{
