@@ -3,12 +3,11 @@ package k8s_test
 import (
 	"testing"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/k8s/v1"
-
 	"github.com/alecthomas/assert"
 	"github.com/ghodss/yaml"
-	api "github.com/kubernetes-client/go-base/config/api"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/k8s/v1"
+	api "github.com/scaleway/scaleway-cli/v2/internal/namespaces/k8s/v1/types"
 )
 
 func Test_GetKubeconfig(t *testing.T) {
@@ -22,6 +21,7 @@ func Test_GetKubeconfig(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				config, err := yaml.Marshal(ctx.Meta["Kubeconfig"].(api.Config))
 				assert.Equal(t, err, nil)
 				assert.Equal(t, ctx.Result.(string), string(config))
