@@ -8,8 +8,8 @@ import (
 	"reflect"
 
 	"github.com/ghodss/yaml"
-	api "github.com/kubernetes-client/go-base/config/api"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	api "github.com/scaleway/scaleway-cli/v2/internal/namespaces/k8s/v1/types"
 	k8s "github.com/scaleway/scaleway-sdk-go/api/k8s/v1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
 )
@@ -95,13 +95,13 @@ func k8sKubeconfigInstallRun(ctx context.Context, argsI interface{}) (i interfac
 	// create the kubeconfig file if it does not exist
 	if _, err := os.Stat(kubeconfigPath); os.IsNotExist(err) {
 		// make sure the directory exists
-		err = os.MkdirAll(path.Dir(kubeconfigPath), 0755)
+		err = os.MkdirAll(path.Dir(kubeconfigPath), 0o755)
 		if err != nil {
 			return nil, err
 		}
 
 		// create the file
-		f, err := os.OpenFile(kubeconfigPath, os.O_CREATE, 0600)
+		f, err := os.OpenFile(kubeconfigPath, os.O_CREATE, 0o600)
 		if err != nil {
 			return nil, err
 		}
