@@ -16,17 +16,15 @@ const (
 	nodeActionTimeout = 10 * time.Minute
 )
 
-var (
-	// nodeStatusMarshalSpecs allows to override the displayed status color
-	nodeStatusMarshalSpecs = human.EnumMarshalSpecs{
-		k8s.NodeStatusCreating:      &human.EnumMarshalSpec{Attribute: color.FgBlue},
-		k8s.NodeStatusRebooting:     &human.EnumMarshalSpec{Attribute: color.FgBlue},
-		k8s.NodeStatusReady:         &human.EnumMarshalSpec{Attribute: color.FgGreen},
-		k8s.NodeStatusNotReady:      &human.EnumMarshalSpec{Attribute: color.FgYellow},
-		k8s.NodeStatusCreationError: &human.EnumMarshalSpec{Attribute: color.FgRed},
-		k8s.NodeStatusLocked:        &human.EnumMarshalSpec{Attribute: color.FgRed},
-	}
-)
+// nodeStatusMarshalSpecs allows to override the displayed status color
+var nodeStatusMarshalSpecs = human.EnumMarshalSpecs{
+	k8s.NodeStatusCreating:      &human.EnumMarshalSpec{Attribute: color.FgBlue},
+	k8s.NodeStatusRebooting:     &human.EnumMarshalSpec{Attribute: color.FgBlue},
+	k8s.NodeStatusReady:         &human.EnumMarshalSpec{Attribute: color.FgGreen},
+	k8s.NodeStatusNotReady:      &human.EnumMarshalSpec{Attribute: color.FgYellow},
+	k8s.NodeStatusCreationError: &human.EnumMarshalSpec{Attribute: color.FgRed},
+	k8s.NodeStatusLocked:        &human.EnumMarshalSpec{Attribute: color.FgRed},
+}
 
 const (
 	nodeActionReboot = iota
@@ -45,8 +43,7 @@ func waitForNodeFunc(action int) core.WaitFunc {
 			Timeout:       scw.TimeDurationPtr(nodeActionTimeout),
 			RetryInterval: core.DefaultRetryInterval,
 		})
-		switch action {
-		case nodeActionReboot:
+		if action == nodeActionReboot {
 			return node, err
 		}
 		return nil, err
