@@ -2,6 +2,7 @@ package lb
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"reflect"
 
@@ -12,13 +13,11 @@ import (
 	"github.com/scaleway/scaleway-sdk-go/scw"
 )
 
-var (
-	certificateStatusMarshalSpecs = human.EnumMarshalSpecs{
-		lb.CertificateStatusError:   &human.EnumMarshalSpec{Attribute: color.FgRed, Value: "error"},
-		lb.CertificateStatusPending: &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "pending"},
-		lb.CertificateStatusReady:   &human.EnumMarshalSpec{Attribute: color.FgGreen, Value: "ready"},
-	}
-)
+var certificateStatusMarshalSpecs = human.EnumMarshalSpecs{
+	lb.CertificateStatusError:   &human.EnumMarshalSpec{Attribute: color.FgRed, Value: "error"},
+	lb.CertificateStatusPending: &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "pending"},
+	lb.CertificateStatusReady:   &human.EnumMarshalSpec{Attribute: color.FgGreen, Value: "ready"},
+}
 
 func lbCertificateMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
 	type tmp lb.Certificate
@@ -114,7 +113,7 @@ func certificateCreateBuilder(c *core.Command) *core.Command {
 		}
 
 		return nil, &core.CliError{
-			Err:  fmt.Errorf("missing required argument"),
+			Err:  errors.New("missing required argument"),
 			Hint: fmt.Sprintf("You need to specify %s or %s", leCommonNameArgSpecs.Name, customeCertificateArgSpecs.Name),
 			Code: 1,
 		}
