@@ -7,8 +7,8 @@ import (
 	"time"
 
 	"github.com/ghodss/yaml"
-	go_api "github.com/kubernetes-client/go-base/config/api"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	go_api "github.com/scaleway/scaleway-cli/v2/internal/namespaces/k8s/v1/types"
 	"github.com/scaleway/scaleway-sdk-go/api/k8s/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/lb/v1"
 )
@@ -63,7 +63,7 @@ func createBackend(forwardPort int32) core.BeforeFunc {
 func addIP2Backend(ip string) core.BeforeFunc {
 	return core.ExecStoreBeforeCmd(
 		"AddIP2Backend",
-		fmt.Sprintf("scw lb backend add-servers {{ .Backend.ID }} server-ip.0=%s", ip),
+		"scw lb backend add-servers {{ .Backend.ID }} server-ip.0="+ip,
 	)
 }
 
@@ -97,7 +97,7 @@ func createClusterAndWaitAndInstallKubeconfig(metaKey string, kubeconfigMetaKey
 		}
 
 		ctx.Meta[kubeconfigMetaKey] = kubeconfig
-		cmd = fmt.Sprintf("scw k8s kubeconfig install %s", cluster.ID)
+		cmd = "scw k8s kubeconfig install " + cluster.ID
 		_ = ctx.ExecuteCmd(strings.Split(cmd, " "))
 		return nil
 	}
