@@ -2,6 +2,7 @@ package rdb
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"io"
 	"net/url"
@@ -23,17 +24,15 @@ const (
 	backupActionTimeout = 20 * time.Minute
 )
 
-var (
-	backupStatusMarshalSpecs = human.EnumMarshalSpecs{
-		rdb.DatabaseBackupStatusUnknown:   &human.EnumMarshalSpec{Attribute: color.Faint, Value: "unknown"},
-		rdb.DatabaseBackupStatusCreating:  &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "creating"},
-		rdb.DatabaseBackupStatusReady:     &human.EnumMarshalSpec{Attribute: color.FgGreen, Value: "ready"},
-		rdb.DatabaseBackupStatusRestoring: &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "restoring"},
-		rdb.DatabaseBackupStatusDeleting:  &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "deleting"},
-		rdb.DatabaseBackupStatusError:     &human.EnumMarshalSpec{Attribute: color.FgRed, Value: "error"},
-		rdb.DatabaseBackupStatusExporting: &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "exporting"},
-	}
-)
+var backupStatusMarshalSpecs = human.EnumMarshalSpecs{
+	rdb.DatabaseBackupStatusUnknown:   &human.EnumMarshalSpec{Attribute: color.Faint, Value: "unknown"},
+	rdb.DatabaseBackupStatusCreating:  &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "creating"},
+	rdb.DatabaseBackupStatusReady:     &human.EnumMarshalSpec{Attribute: color.FgGreen, Value: "ready"},
+	rdb.DatabaseBackupStatusRestoring: &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "restoring"},
+	rdb.DatabaseBackupStatusDeleting:  &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "deleting"},
+	rdb.DatabaseBackupStatusError:     &human.EnumMarshalSpec{Attribute: color.FgRed, Value: "error"},
+	rdb.DatabaseBackupStatusExporting: &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "exporting"},
+}
 
 type backupWaitRequest struct {
 	BackupID string
@@ -288,6 +287,7 @@ func backupDownloadCommand() *core.Command {
 				Timeout:          scw.TimeDurationPtr(backupActionTimeout),
 				RetryInterval:    core.DefaultRetryInterval,
 			}
+
 			backup, err := api.WaitForDatabaseBackup(backupRequest)
 			if err != nil {
 				return nil, err
@@ -320,6 +320,11 @@ func backupDownloadCommand() *core.Command {
 			}
 
 			httpClient := core.ExtractHTTPClient(ctx)
+
+			if backup.DownloadURL == nil {
+				return nil, errors.New("download URL is still nil after export")
+			}
+
 			res, err := httpClient.Get(*backup.DownloadURL)
 			if err != nil {
 				return nil, err
