@@ -2,11 +2,12 @@ package rdb_test
 
 import (
 	"fmt"
+	"net"
+	"strconv"
 	"testing"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/rdb/v1"
-
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/rdb/v1"
 	"github.com/stretchr/testify/assert"
 )
 
@@ -20,9 +21,10 @@ func Test_UserGetURL(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				ip := ctx.Meta["Instance"].(rdb.CreateInstanceResult).Instance.Endpoints[0].IP
 				port := ctx.Meta["Instance"].(rdb.CreateInstanceResult).Instance.Endpoints[0].Port
-				expected := fmt.Sprintf("postgresql://%s@%s:%d", user, ip, port)
+				expected := fmt.Sprintf("postgresql://%s@%s", user, net.JoinHostPort(ip.String(), strconv.Itoa(int(port))))
 				assert.Equal(t, expected, ctx.Result)
 			},
 		),
@@ -38,9 +40,10 @@ func Test_UserGetURL(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				ip := ctx.Meta["Instance"].(rdb.CreateInstanceResult).Instance.Endpoints[0].IP
 				port := ctx.Meta["Instance"].(rdb.CreateInstanceResult).Instance.Endpoints[0].Port
-				expected := fmt.Sprintf("mysql://%s@%s:%d", user, ip, port)
+				expected := fmt.Sprintf("mysql://%s@%s", user, net.JoinHostPort(ip.String(), strconv.Itoa(int(port))))
 				assert.Equal(t, expected, ctx.Result)
 			},
 		),
@@ -57,13 +60,14 @@ func Test_UserGetURL(t *testing.T) {
 			createInstance("PostgreSQL-12"),
 			core.ExecBeforeCmd(fmt.Sprintf("scw rdb user create instance-id={{ $.Instance.ID }} name=%s password=%s is-admin=false", customUserName, customUserPassword)),
 		),
-		Cmd: fmt.Sprintf("scw rdb user get-url {{ $.Instance.ID }} user=%s", customUserName),
+		Cmd: "scw rdb user get-url {{ $.Instance.ID }} user=" + customUserName,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				ip := ctx.Meta["Instance"].(rdb.CreateInstanceResult).Instance.Endpoints[0].IP
 				port := ctx.Meta["Instance"].(rdb.CreateInstanceResult).Instance.Endpoints[0].Port
-				expected := fmt.Sprintf("postgresql://%s@%s:%d", customUserName, ip, port)
+				expected := fmt.Sprintf("postgresql://%s@%s", customUserName, net.JoinHostPort(ip.String(), strconv.Itoa(int(port))))
 				assert.Equal(t, expected, ctx.Result)
 			},
 		),
@@ -74,15 +78,16 @@ func Test_UserGetURL(t *testing.T) {
 		Commands: rdb.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
 			createInstance("PostgreSQL-12"),
-			core.ExecBeforeCmd(fmt.Sprintf("scw rdb database create instance-id={{ $.Instance.ID }} name=%s", customDBName)),
+			core.ExecBeforeCmd("scw rdb database create instance-id={{ $.Instance.ID }} name="+customDBName),
 		),
-		Cmd: fmt.Sprintf("scw rdb user get-url {{ $.Instance.ID }} db=%s", customDBName),
+		Cmd: "scw rdb user get-url {{ $.Instance.ID }} db=" + customDBName,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				ip := ctx.Meta["Instance"].(rdb.CreateInstanceResult).Instance.Endpoints[0].IP
 				port := ctx.Meta["Instance"].(rdb.CreateInstanceResult).Instance.Endpoints[0].Port
-				expected := fmt.Sprintf("postgresql://%s@%s:%d/%s", user, ip, port, customDBName)
+				expected := fmt.Sprintf("postgresql://%s@%s/%s", user, net.JoinHostPort(ip.String(), strconv.Itoa(int(port))), customDBName)
 				assert.Equal(t, expected, ctx.Result)
 			},
 		),
@@ -100,9 +105,10 @@ func Test_DatabaseGetURL(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				ip := ctx.Meta["Instance"].(rdb.CreateInstanceResult).Instance.Endpoints[0].IP
 				port := ctx.Meta["Instance"].(rdb.CreateInstanceResult).Instance.Endpoints[0].Port
-				expected := fmt.Sprintf("postgresql://%s@%s:%d", user, ip, port)
+				expected := fmt.Sprintf("postgresql://%s@%s", user, net.JoinHostPort(ip.String(), strconv.Itoa(int(port))))
 				assert.Equal(t, expected, ctx.Result)
 			},
 		),
