@@ -3,9 +3,9 @@ package redis
 import (
 	"context"
 	"errors"
-	"log"
 	"net/http"
 	"reflect"
+	"strings"
 	"time"
 
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
@@ -16,6 +16,11 @@ import (
 
 const redisActionTimeout = 15 * time.Minute
 
+func redisClusterMigrateBuilder(c *core.Command) *core.Command {
+	c.ArgSpecs.GetByName("node-type").AutoCompleteFunc = autoCompleteNodeType
+	return c
+}
+
 func clusterCreateBuilder(c *core.Command) *core.Command {
 	type redisEndpointSpecPrivateNetworkSpecCustom struct {
 		*redis.EndpointSpecPrivateNetworkSpec
@@ -159,34 +164,14 @@ func ACLAddListBuilder(c *core.Command) *core.Command {
 	return c
 }
 
-func redisEndpointsClusterGetMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
-	type tmp []*redis.Endpoint
-	redisEndpointsClusterResponse := tmp(i.([]*redis.Endpoint))
-	opt.Fields = []*human.MarshalFieldOpt{
-		{
-			FieldName: "ID",
-			Label:     "ID",
-		},
-		{
-			FieldName: "Port",
-			Label:     "Port",
-		},
-		{
-			FieldName: "IPs",
-			Label:     "IPs",
-		},
-	}
-	str, err := human.Marshal(redisEndpointsClusterResponse, opt)
-	if err != nil {
-		return "", err
-	}
-	return str, nil
+func redisSettingAddBuilder(c *core.Command) *core.Command {
+	c.ArgSpecs.GetByName("settings.{index}.name").AutoCompleteFunc = autoCompleteSettingsName
+	return c
 }
 
 func redisClusterGetMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
 	type tmp redis.Cluster
 	redisClusterResponse := tmp(i.(redis.Cluster))
-	log.Println("redis ", i.(redis.Cluster).Endpoints[0])
 	opt.Sections = []*human.MarshalSection{
 		{
 			FieldName: "Endpoints",
@@ -197,6 +182,24 @@ func redisClusterGetMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string,
 			Title:     "ACLRules",
 		},
 	}
+	opt.SubOptions = map[string]*human.MarshalOpt{
+		"Endpoints": {
+			Fields: []*human.MarshalFieldOpt{
+				{
+					FieldName: "ID",
+					Label:     "ID",
+				},
+				{
+					FieldName: "Port",
+					Label:     "Port",
+				},
+				{
+					FieldName: "IPs",
+					Label:     "IPs",
+				},
+			},
+		},
+	}
 	str, err := human.Marshal(redisClusterResponse, opt)
 	if err != nil {
 		return "", err
@@ -204,3 +207,70 @@ func redisClusterGetMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string,
 
 	return str, nil
 }
+
+var completeClusterCache *redis.Cluster
+
+var completeClusterVersionCache *redis.ListClusterVersionsResponse
+
+func autoCompleteSettingsName(ctx context.Context, prefix string, request any) core.AutocompleteSuggestions {
+	suggestions := core.AutocompleteSuggestions(nil)
+	req := request.(*redis.AddClusterSettingsRequest)
+	client := core.ExtractClient(ctx)
+	api := redis.NewAPI(client)
+	if req.ClusterID != "" {
+		if completeClusterCache == nil {
+			res, err := api.GetCluster(&redis.GetClusterRequest{
+				ClusterID: req.ClusterID,
+			})
+			if err != nil {
+				return nil
+			}
+			completeClusterCache = res
+		}
+		if completeClusterVersionCache == nil {
+			res, err := api.ListClusterVersions(&redis.ListClusterVersionsRequest{
+				Zone:    completeClusterCache.Zone,
+				Version: &completeClusterCache.Version,
+			})
+			if err != nil {
+				return nil
+			}
+			completeClusterVersionCache = res
+		}
+
+		for _, version := range completeClusterVersionCache.Versions {
+			for _, settingName := range version.AvailableSettings {
+				if strings.HasPrefix(settingName.Name, prefix) {
+					suggestions = append(suggestions, settingName.Name)
+				}
+			}
+		}
+	}
+	return suggestions
+}
+
+var completeRedisNoteTypeCache *redis.ListNodeTypesResponse
+
+func autoCompleteNodeType(ctx context.Context, prefix string, request any) core.AutocompleteSuggestions {
+	suggestions := core.AutocompleteSuggestions(nil)
+	req := request.(*redis.MigrateClusterRequest)
+	client := core.ExtractClient(ctx)
+	api := redis.NewAPI(client)
+	if req.Zone != "" {
+		if completeRedisNoteTypeCache == nil {
+			res, err := api.ListNodeTypes(&redis.ListNodeTypesRequest{
+				Zone: req.Zone,
+			})
+			if err != nil {
+				return nil
+			}
+			completeRedisNoteTypeCache = res
+		}
+		for _, nodeType := range completeRedisNoteTypeCache.NodeTypes {
+			if strings.HasPrefix(nodeType.Name, prefix) {
+				suggestions = append(suggestions, nodeType.Name)
+			}
+		}
+	}
+	return suggestions
+}
