@@ -6,10 +6,9 @@ import (
 	"testing"
 	"time"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/redis/v1"
-
 	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/redis/v1"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/vpc/v2"
 	redisSDK "github.com/scaleway/scaleway-sdk-go/api/redis/v1"
 )
@@ -38,6 +37,7 @@ func Test_Endpoints(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
 				checkEndpoints(t, endpoints, 1, 0, 0)
 			},
@@ -61,6 +61,7 @@ func Test_Endpoints(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
 				checkEndpoints(t, endpoints, 0, 1, 0)
 			},
@@ -90,6 +91,7 @@ func Test_Endpoints(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
 				checkEndpoints(t, endpoints, 0, 2, 0)
 			},
@@ -123,6 +125,7 @@ func Test_IpamConfig(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
 				checkEndpoints(t, endpoints, 0, 0, 1)
 			},
@@ -152,6 +155,7 @@ func Test_IpamConfig(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
 				checkEndpoints(t, endpoints, 0, 0, 2)
 			},
@@ -182,6 +186,7 @@ func Test_IpamConfig(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
 				checkEndpoints(t, endpoints, 0, 1, 1)
 			},
@@ -218,6 +223,7 @@ func Test_EndpointsEdgeCases(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckExitCode(1),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				assert.Contains(t, ctx.Err.Error(), expectedError)
 			},
 		),
@@ -243,6 +249,7 @@ func Test_EndpointsEdgeCases(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckExitCode(1),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
 				assert.Contains(t, ctx.Err.Error(), expectedError)
 			},
 		),
@@ -261,19 +268,21 @@ func deletePrivateNetwork(metaName string) core.AfterFunc {
 }
 
 func checkEndpoints(t *testing.T, endpoints []*redisSDK.Endpoint, nbExpectedPub, nbExpectedPrivStatic, nbExpectedPrivIpam int) {
+	t.Helper()
 	expectedEndpoints := map[string]int{
 		"public":         nbExpectedPub,
 		"private-static": nbExpectedPrivStatic,
 		"private-ipam":   nbExpectedPrivIpam,
 	}
 	for _, endpoint := range endpoints {
-		if endpoint.PrivateNetwork == nil {
+		switch {
+		case endpoint.PrivateNetwork == nil:
 			expectedEndpoints["public"]--
-		} else if endpoint.PrivateNetwork.ProvisioningMode == redisSDK.PrivateNetworkProvisioningModeStatic {
+		case endpoint.PrivateNetwork.ProvisioningMode == redisSDK.PrivateNetworkProvisioningModeStatic:
 			expectedEndpoints["private-static"]--
-		} else if endpoint.PrivateNetwork.ProvisioningMode == redisSDK.PrivateNetworkProvisioningModeIpam {
+		case endpoint.PrivateNetwork.ProvisioningMode == redisSDK.PrivateNetworkProvisioningModeIpam:
 			expectedEndpoints["private-ipam"]--
-		} else {
+		default:
 			t.Error("unknown endpoint type")
 		}
 	}
